/* This file was generated by syncqt. */
#ifndef QT_QTVIRTUALKEYBOARD_VERSION_H
#define QT_QTVIRTUALKEYBOARD_VERSION_H

#define QTVIRTUALKEYBOARD_VERSION_STR "5.15.19"

#define QTVIRTUALKEYBOARD_VERSION 0x050F13

#endif // QT_QTVIRTUALKEYBOARD_VERSION_H
